@@ -160,10 +160,7 @@ rsvg_handle_init (RsvgHandle * self)
     self->priv->dpi_x = rsvg_internal_dpi_x;
     self->priv->dpi_y = rsvg_internal_dpi_y;
 
-    self->priv->css_props = g_hash_table_new_full (g_str_hash,
-                                                   g_str_equal,
-                                                   g_free,
-                                                   (GDestroyNotify) g_hash_table_destroy);
+    self->priv->css_styles = rsvg_css_styles_new ();
 
     self->priv->tree = NULL;
 
@@ -191,7 +188,7 @@ rsvg_handle_dispose (GObject *instance)
 
     g_clear_pointer (&self->priv->load, rsvg_load_free);
     g_clear_pointer (&self->priv->defs, rsvg_defs_free);
-    g_clear_pointer (&self->priv->css_props, g_hash_table_destroy);
+    g_clear_pointer (&self->priv->css_styles, rsvg_css_styles_free);
     g_clear_pointer (&self->priv->tree, rsvg_tree_free);
     g_clear_pointer (&self->priv->base_uri, g_free);
     g_clear_object (&self->priv->base_gfile);
@@ -1001,6 +998,12 @@ rsvg_handle_get_defs (RsvgHandle *handle)
     return handle->priv->defs;
 }
 
+RsvgCssStyles *
+rsvg_handle_get_css_styles (RsvgHandle *handle)
+{
+    return handle->priv->css_styles;
+}
+
 RsvgHandle *
 rsvg_handle_load_extern (RsvgHandle *handle, const char *uri)
 {
@@ -1224,7 +1227,7 @@ rsvg_handle_get_dimensions_sub (RsvgHandle * handle, RsvgDimensionData * dimensi
     if (id && *id) {
         node = rsvg_defs_lookup (handle->priv->defs, id);
 
-        if (rsvg_tree_is_root (handle->priv->tree, node))
+        if (node && rsvg_tree_is_root (handle->priv->tree, node))
             id = NULL;
     } else {
         node = root;
@@ -1761,6 +1764,10 @@ rsvg_cairo_surface_new_from_href (RsvgHandle *handle,
     }
 
     surface = rsvg_cairo_surface_from_pixbuf (pixbuf);
+    if (!surface) {
+        g_set_error (error, RSVG_ERROR, RSVG_ERROR_FAILED, "could not convert pixbuf to cairo surface");
+        goto out;
+    }
 
     if (mime_type == NULL) {
         /* Try to get the information from the loader */
