@@ -492,7 +492,7 @@ impl<'a> DrawingCtx<'a> {
 
                 if !filter_node.is_in_error() {
                     // FIXME: deal with out of memory here
-                    Ok(filters::render(&filter_node, values, &output, self))
+                    filters::render(&filter_node, values, &output, self)
                 } else {
                     Ok(child_surface.clone())
                 }
@@ -516,7 +516,23 @@ impl<'a> DrawingCtx<'a> {
         let cr = self.get_cairo_context();
         pangocairo::functions::update_context(&cr, &context);
 
-        set_resolution(&context, self.dpi_x);
+        // Pango says this about pango_cairo_context_set_resolution():
+        //
+        //     Sets the resolution for the context. This is a scale factor between
+        //     points specified in a #PangoFontDescription and Cairo units. The
+        //     default value is 96, meaning that a 10 point font will be 13
+        //     units high. (10 * 96. / 72. = 13.3).
+        //
+        // I.e. Pango font sizes in a PangoFontDescription are in *points*, not pixels.
+        // However, we are normalizing everything to userspace units, which amount to
+        // pixels.  So, we will use 72.0 here to make Pango not apply any further scaling
+        // to the size values we give it.
+        //
+        // An alternative would be to divide our font sizes by (dpi_y / 72) to effectively
+        // cancel out Pango's scaling, but it's probably better to deal with Pango-isms
+        // right here, instead of spreading them out through our Length normalization
+        // code.
+        set_resolution(&context, 72.0);
 
         if self.is_testing {
             let mut options = cairo::FontOptions::new();
@@ -864,30 +880,30 @@ fn compute_text_bbox(
 ) -> BoundingBox {
     let pango_scale = f64::from(pango::SCALE);
 
-    let mut bbox = BoundingBox::new(affine);
-
     let ink_x = f64::from(ink.x);
     let ink_y = f64::from(ink.y);
     let ink_width = f64::from(ink.width);
     let ink_height = f64::from(ink.height);
 
-    if gravity_is_vertical(gravity) {
-        bbox.rect = Some(cairo::Rectangle {
+    let rect = if gravity_is_vertical(gravity) {
+        cairo::Rectangle {
             x: x + (ink_x - ink_height) / pango_scale,
             y: y + ink_y / pango_scale,
             width: ink_height / pango_scale,
             height: ink_width / pango_scale,
-        });
+        }
     } else {
-        bbox.rect = Some(cairo::Rectangle {
+        cairo::Rectangle {
             x: x + ink_x / pango_scale,
             y: y + ink_y / pango_scale,
             width: ink_width / pango_scale,
             height: ink_height / pango_scale,
-        });
-    }
+        }
+    };
 
-    bbox
+    BoundingBox::new(affine)
+        .with_rect(Some(rect))
+        .with_ink_rect(Some(rect))
 }
 
 fn compute_stroke_and_fill_box(cr: &cairo::Context, values: &ComputedValues) -> BoundingBox {
