@@ -27,6 +27,13 @@ extern crate downcast_rs;
 
 pub use color::{rsvg_css_parse_color, ColorKind, ColorSpec};
 
+pub use css::{
+    rsvg_css_parse_into_handle,
+    rsvg_css_styles_define,
+    rsvg_css_styles_free,
+    rsvg_css_styles_new,
+};
+
 pub use defs::{rsvg_defs_free, rsvg_defs_lookup, rsvg_defs_new};
 
 pub use drawing_ctx::{
@@ -59,8 +66,6 @@ pub use tree::{
     rsvg_tree_root_is_svg,
 };
 
-pub use parsers::rsvg_css_parse_number_optional_number;
-
 pub use property_bag::{
     rsvg_property_bag_free,
     rsvg_property_bag_iter_begin,
@@ -69,8 +74,6 @@ pub use property_bag::{
     rsvg_property_bag_new,
 };
 
-pub use state::rsvg_state_parse_style_pair;
-
 pub use structure::rsvg_node_svg_get_size;
 
 pub use text::{rsvg_node_chars_append, rsvg_node_chars_new};
@@ -93,6 +96,8 @@ mod bbox;
 mod clip_path;
 mod color;
 mod cond;
+mod croco;
+mod css;
 mod defs;
 mod drawing_ctx;
 mod error;
