@@ -36,9 +36,9 @@ impl Default for MarkerUnits {
 
 impl Parse for MarkerUnits {
     type Data = ();
-    type Err = AttributeError;
+    type Err = ValueErrorKind;
 
-    fn parse(parser: &mut Parser, _: ()) -> Result<MarkerUnits, AttributeError> {
+    fn parse(parser: &mut Parser<'_, '_>, _: ()) -> Result<MarkerUnits, ValueErrorKind> {
         let loc = parser.current_source_location();
 
         parser
@@ -52,7 +52,7 @@ impl Parse for MarkerUnits {
                     ))),
                 ),
             }).map_err(|_| {
-                AttributeError::Parse(ParseError::new(
+                ValueErrorKind::Parse(ParseError::new(
                     "expected \"userSpaceOnUse\" or \"strokeWidth\"",
                 ))
             })
@@ -74,15 +74,15 @@ impl Default for MarkerOrient {
 
 impl Parse for MarkerOrient {
     type Data = ();
-    type Err = AttributeError;
+    type Err = ValueErrorKind;
 
-    fn parse(parser: &mut Parser, _: ()) -> Result<MarkerOrient, AttributeError> {
+    fn parse(parser: &mut Parser<'_, '_>, _: ()) -> Result<MarkerOrient, ValueErrorKind> {
         if parser.try(|p| p.expect_ident_matching("auto")).is_ok() {
             Ok(MarkerOrient::Auto)
         } else {
             parsers::angle_degrees(parser)
                 .map(MarkerOrient::Degrees)
-                .map_err(AttributeError::Parse)
+                .map_err(ValueErrorKind::Parse)
         }
     }
 }
@@ -120,7 +120,7 @@ impl NodeMarker {
     fn render(
         &self,
         node: &RsvgNode,
-        draw_ctx: &mut DrawingCtx,
+        draw_ctx: &mut DrawingCtx<'_>,
         xpos: f64,
         ypos: f64,
         computed_angle: f64,
@@ -130,8 +130,10 @@ impl NodeMarker {
         let cascaded = node.get_cascaded_values();
         let values = cascaded.get();
 
-        let marker_width = self.width.get().normalize(&values, draw_ctx);
-        let marker_height = self.height.get().normalize(&values, draw_ctx);
+        let params = draw_ctx.get_view_params();
+
+        let marker_width = self.width.get().normalize(&values, &params);
+        let marker_height = self.height.get().normalize(&values, &params);
 
         if marker_width.approx_eq_cairo(&0.0) || marker_height.approx_eq_cairo(&0.0) {
             // markerWidth or markerHeight set to 0 disables rendering of the element
@@ -156,7 +158,7 @@ impl NodeMarker {
             affine.scale(line_width, line_width);
         }
 
-        if let Some(vbox) = self.vbox.get() {
+        let params = if let Some(vbox) = self.vbox.get() {
             let (_, _, w, h) = self.aspect.get().compute(
                 vbox.0.width,
                 vbox.0.height,
@@ -172,14 +174,14 @@ impl NodeMarker {
 
             affine.scale(w / vbox.0.width, h / vbox.0.height);
 
-            draw_ctx.push_view_box(vbox.0.width, vbox.0.height);
+            draw_ctx.push_view_box(vbox.0.width, vbox.0.height)
         } else {
-            draw_ctx.push_view_box(marker_width, marker_height);
-        }
+            draw_ctx.push_view_box(marker_width, marker_height)
+        };
 
         affine.translate(
-            -self.ref_x.get().normalize(&values, draw_ctx),
-            -self.ref_y.get().normalize(&values, draw_ctx),
+            -self.ref_x.get().normalize(&values, &params),
+            -self.ref_y.get().normalize(&values, &params),
         );
 
         cr.save();
@@ -198,8 +200,6 @@ impl NodeMarker {
             node.draw_children(&cascaded, dc, clipping)
         });
 
-        draw_ctx.pop_view_box();
-
         cr.restore();
 
         res
@@ -207,7 +207,12 @@ impl NodeMarker {
 }
 
 impl NodeTrait for NodeMarker {
-    fn set_atts(&self, node: &RsvgNode, _: *const RsvgHandle, pbag: &PropertyBag) -> NodeResult {
+    fn set_atts(
+        &self,
+        node: &RsvgNode,
+        _: *const RsvgHandle,
+        pbag: &PropertyBag<'_>,
+    ) -> NodeResult {
         // marker element has overflow:hidden
         // https://www.w3.org/TR/SVG/styling.html#UAStyleSheet
         node.set_overflow_hidden();
@@ -627,7 +632,7 @@ enum MarkerType {
 }
 
 fn emit_marker_by_name(
-    draw_ctx: &mut DrawingCtx,
+    draw_ctx: &mut DrawingCtx<'_>,
     name: &str,
     xpos: f64,
     ypos: f64,
@@ -684,11 +689,14 @@ where
 
 pub fn render_markers_for_path_builder(
     builder: &PathBuilder,
-    draw_ctx: &mut DrawingCtx,
+    draw_ctx: &mut DrawingCtx<'_>,
     values: &ComputedValues,
     clipping: bool,
 ) -> Result<(), RenderingError> {
-    let line_width = values.stroke_width.0.normalize(values, draw_ctx);
+    let line_width = values
+        .stroke_width
+        .0
+        .normalize(values, &draw_ctx.get_view_params());
 
     if line_width.approx_eq_cairo(&0.0) {
         return Ok(());
@@ -871,10 +879,10 @@ mod parser_tests {
     #[test]
     fn parsing_invalid_marker_units_yields_error() {
         assert!(is_parse_error(
-            &MarkerUnits::parse_str("", ()).map_err(|e| AttributeError::from(e))
+            &MarkerUnits::parse_str("", ()).map_err(|e| ValueErrorKind::from(e))
         ));
         assert!(is_parse_error(
-            &MarkerUnits::parse_str("foo", ()).map_err(|e| AttributeError::from(e))
+            &MarkerUnits::parse_str("foo", ()).map_err(|e| ValueErrorKind::from(e))
         ));
     }
 
@@ -893,13 +901,13 @@ mod parser_tests {
     #[test]
     fn parsing_invalid_marker_orient_yields_error() {
         assert!(is_parse_error(
-            &MarkerOrient::parse_str("", ()).map_err(|e| AttributeError::from(e))
+            &MarkerOrient::parse_str("", ()).map_err(|e| ValueErrorKind::from(e))
         ));
         assert!(is_parse_error(
-            &MarkerOrient::parse_str("blah", ()).map_err(|e| AttributeError::from(e))
+            &MarkerOrient::parse_str("blah", ()).map_err(|e| ValueErrorKind::from(e))
         ));
         assert!(is_parse_error(
-            &MarkerOrient::parse_str("45blah", ()).map_err(|e| AttributeError::from(e))
+            &MarkerOrient::parse_str("45blah", ()).map_err(|e| ValueErrorKind::from(e))
         ));
     }
 
