@@ -55,6 +55,7 @@ get_test_filename (const char *basename) {
 
 #define EXAMPLE_ONE_ID "#one"
 #define EXAMPLE_TWO_ID "#two"
+#define EXAMPLE_NONEXISTENT_ID "#nonexistent"
 
 #define EXAMPLE_ONE_X 0
 #define EXAMPLE_ONE_Y 0
@@ -462,6 +463,9 @@ dimensions_and_position (void)
     g_assert_cmpint (pos.x, ==, EXAMPLE_TWO_X);
     g_assert_cmpint (pos.y, ==, EXAMPLE_TWO_Y);
 
+    g_assert (!rsvg_handle_get_position_sub (handle, &pos, EXAMPLE_NONEXISTENT_ID));
+    g_assert (!rsvg_handle_get_dimensions_sub (handle, &dim, EXAMPLE_NONEXISTENT_ID));
+
     g_object_unref (handle);
 }
 
